@@ -1,7 +1,10 @@
+from datetime import datetime
+from typing import Any
+
 from requests import Session
 
 from ..devices.gateway import Gateway
-from ..exceptions.device import WrongElementError
+from ..exceptions.device import SwitchingProtected, WrongElementError
 from .property import Property
 
 
@@ -12,15 +15,30 @@ class BinarySwitchProperty(Property):
     :param gateway: Instance of a Gateway object
     :param session: Instance of a requests.Session object
     :param element_uid: Element UID, something like devolo.BinarySwitch:hdm:ZWave:CBC56091/24#2
-    :param state: State the switch has at time of creating this instance
+    :key enabled: State of the remote protection setting
+    :key state: State the switch has at time of creating this instance
     """
 
-    def __init__(self, gateway: Gateway, session: Session, element_uid: str, state: bool):
+    def __init__(self, gateway: Gateway, session: Session, element_uid: str, **kwargs: Any):
         if not element_uid.startswith("devolo.BinarySwitch:"):
             raise WrongElementError(f"{element_uid} is not a Binary Switch.")
 
         super().__init__(gateway=gateway, session=session, element_uid=element_uid)
-        self.state = state
+
+        self._state = kwargs.get("state", False)
+        self.enabled = kwargs.get("enabled", False)
+
+
+    @property
+    def state(self) -> bool:
+        """ State of the binary sensor. """
+        return self._state
+
+    @state.setter
+    def state(self, state: bool):
+        """ Update state of the binary sensor and set point in time of the last_activity. """
+        self._state = state
+        self._last_activity = datetime.now()
 
 
     def set(self, state: bool):
@@ -29,10 +47,13 @@ class BinarySwitchProperty(Property):
 
         :param state: True if switching on, False if switching off
         """
+        if not self.enabled:
+            raise SwitchingProtected("This device is protected against remote switching.")
+
         data = {"method": "FIM/invokeOperation",
                 "params": [self.element_uid, "turnOn" if state else "turnOff", []]}
         response = self.post(data)
-        if response.get("result").get("status") == 1:
+        if response["result"].get("status") == 1:
             self.state = state
             self._logger.debug(f"Binary switch property {self.element_uid} set to {state}")
         else:
