@@ -1,3 +1,4 @@
+from datetime import datetime
 from typing import Any
 
 from requests import Session
@@ -25,15 +26,15 @@ class MultiLevelSensorProperty(SensorProperty):
         if not element_uid.startswith(("devolo.DewpointSensor:",
                                        "devolo.MultiLevelSensor:",
                                        "devolo.SirenMultiLevelSensor:",
+                                       "devolo.ValveTemperatureSensor",
                                        "devolo.VoltageMultiLevelSensor:")):
             raise WrongElementError(f"{element_uid} is not a Multi Level Sensor.")
 
-        self._unit = ""
-
         super().__init__(gateway=gateway, session=session, element_uid=element_uid, **kwargs)
 
-        self.value = kwargs.get("value")
-        self.unit = kwargs.get("unit")
+        self._value = kwargs.get("value", 0.0)
+        self._unit = ""
+        self.unit = kwargs.get("unit", "")
 
 
     @property
@@ -44,15 +45,26 @@ class MultiLevelSensorProperty(SensorProperty):
     @unit.setter
     def unit(self, unit: int):
         """ Make the numeric unit human readable, if known. """
-        units = {"dewpoint": {0: "°C"},
-                 "humidity": {0: "%"},
+        units = {"dewpoint": {0: "°C", 1: "°F"},
+                 "humidity": {0: "%", 1: "g/m³"},
                  "light": {0: "%", 1: "lx"},
-                 "temperature": {0: "°C"},
+                 "temperature": {0: "°C", 1: "°F"},
                  "Seismic Intensity": {0: ""},
-                 "voltage": {0: "V"}
+                 "voltage": {0: "V", 1: "mV"}
                  }
-        if units.get(self.sensor_type) is not None:
+        try:
             self._unit = units[self.sensor_type].get(unit, str(unit))
-        else:
+        except KeyError:
             self._unit = str(unit)
         self._logger.debug(f"Unit of {self.element_uid} set to '{self._unit}'.")
+
+    @property
+    def value(self) -> float:
+        """ Multi level value. """
+        return self._value
+
+    @value.setter
+    def value(self, value: float):
+        """ Update value of the multilevel sensor and set point in time of the last_activity. """
+        self._value = value
+        self._last_activity = datetime.now()
