@@ -8,16 +8,16 @@ class TestPublisher:
     def test_register_unregister(self):
         for device in self.homecontrol.devices:
             self.homecontrol.devices[device].subscriber = Subscriber(device)
-            self.homecontrol.mprm.publisher.register(device, self.homecontrol.devices[device].subscriber)
+            self.homecontrol.publisher.register(device, self.homecontrol.devices[device].subscriber)
             assert len(self.homecontrol.publisher._get_subscribers_for_specific_event(device)) == 1
         for device in self.homecontrol.devices:
-            self.homecontrol.mprm.publisher.unregister(device, self.homecontrol.devices[device].subscriber)
+            self.homecontrol.publisher.unregister(device, self.homecontrol.devices[device].subscriber)
             assert len(self.homecontrol.publisher._get_subscribers_for_specific_event(device)) == 0
 
     def test_dispatch(self):
         for device in self.homecontrol.devices:
             self.homecontrol.devices[device].subscriber = Subscriber(device)
-            self.homecontrol.mprm.publisher.register(device, self.homecontrol.devices[device].subscriber)
+            self.homecontrol.publisher.register(device, self.homecontrol.devices[device].subscriber)
         with pytest.raises(FileExistsError):
             self.homecontrol.publisher.dispatch(event="hdm:ZWave:F6BF9812/4", message=())
 
